==> jboss-3.2.6-src.tar.bz2: jboss-3.2.6-src/jaxrpc/src/main/org/apache/axis/deployment/wsdd/WSDDDocument.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2001-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
package org.apache.axis.deployment.wsdd;

import org.apache.axis.ConfigurationException;
import org.apache.axis.components.logger.LogFactory;
import org.apache.axis.encoding.SerializationContext;
import org.apache.axis.encoding.SerializationContextImpl;
import org.apache.axis.utils.Messages;
import org.apache.axis.utils.XMLUtils;
import org.apache.commons.logging.Log;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.InputSource;

import java.io.IOException;
import java.io.StringReader;
import java.io.StringWriter;


/**
 * represents a WSDD Document (this is the top level object in this object model)
 */
public class WSDDDocument extends WSDDConstants
{
   private static Log log =
           LogFactory.getLog(WSDDDocument.class.getName());

   private Document doc;

   private WSDDDeployment deployment;
   private WSDDUndeployment undeployment;

   /**
    *
    */
   public WSDDDocument()
   {
   }

   /**
    * @param doc (Document) XXX
    */
   public WSDDDocument(Document doc) throws WSDDException
   {
      this.doc = doc;
      Element docEl = doc.getDocumentElement();
      if (ELEM_WSDD_UNDEPLOY.equals(docEl.getLocalName()))
      {
         undeployment = new WSDDUndeployment(docEl);
      }
      else
      {
         deployment = new WSDDDeployment(docEl);
      }
   }

   /**
    * @param e (Element) XXX
    */
   public WSDDDocument(Element e) throws WSDDException
   {
      doc = e.getOwnerDocument();
      if (ELEM_WSDD_UNDEPLOY.equals(e.getLocalName()))
      {
         undeployment = new WSDDUndeployment(e);
      }
      else
      {
         deployment = new WSDDDeployment(e);
      }
   }

   /**
    * @return XXX
    */
   public WSDDDeployment getDeployment()
   {
      if (deployment == null)
         deployment = new WSDDDeployment();
      return deployment;
   }

   public Document getDOMDocument() throws ConfigurationException
   {
      StringWriter writer = new StringWriter();
      SerializationContext context = new SerializationContextImpl(writer, null);
      context.setPretty(true);
      try
      {
         deployment.writeToContext(context);
      }
      catch (Exception e)
      {
         log.error(Messages.getMessage("exception00"), e);
      }
      try
      {
         writer.close();
         return XMLUtils.newDocument(new InputSource(new StringReader(writer.getBuffer().toString())));
      }
      catch (Exception e)
      {
         return null;
      }
   }

   public void writeToContext(SerializationContext context)
           throws IOException
   {
      getDeployment().writeToContext(context);
   }

   /**
    * @param document XXX
    */
   public void setDocument(Document document)
   {
      doc = document;

      deployment = null;
   }

   public void deploy(WSDDDeployment registry) throws ConfigurationException
   {
      if (deployment != null)
      {
         deployment.deployToRegistry(registry);
      }
      if (undeployment != null)
      {
         undeployment.undeployFromRegistry(registry);
      }
   }
}

==> jboss-3.2.7-src.tar.bz2: jboss-3.2.7-src/jaxrpc/src/main/org/apache/axis/deployment/wsdd/WSDDDocument.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2001-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
package org.apache.axis.deployment.wsdd;

import org.apache.axis.ConfigurationException;
import org.apache.axis.encoding.SerializationContext;
import org.apache.axis.encoding.SerializationContextImpl;
import org.apache.axis.utils.Messages;
import org.apache.axis.utils.XMLUtils;
import org.jboss.logging.Logger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.InputSource;

import java.io.IOException;
import java.io.StringReader;
import java.io.StringWriter;


/**
 * represents a WSDD Document (this is the top level object in this object model)
 */
public class WSDDDocument extends WSDDConstants
{
   private static Logger log = Logger.getLogger(WSDDDocument.class.getName());

   private Document doc;

   private WSDDDeployment deployment;
   private WSDDUndeployment undeployment;

   /**
    *
    */
   public WSDDDocument()
   {
   }

   /**
    * @param doc (Document) XXX
    */
   public WSDDDocument(Document doc) throws WSDDException
   {
      this.doc = doc;
      Element docEl = doc.getDocumentElement();
      if (ELEM_WSDD_UNDEPLOY.equals(docEl.getLocalName()))
      {
         undeployment = new WSDDUndeployment(docEl);
      }
      else
      {
         deployment = new WSDDDeployment(docEl);
      }
   }

   /**
    * @param e (Element) XXX
    */
   public WSDDDocument(Element e) throws WSDDException
   {
      doc = e.getOwnerDocument();
      if (ELEM_WSDD_UNDEPLOY.equals(e.getLocalName()))
      {
         undeployment = new WSDDUndeployment(e);
      }
      else
      {
         deployment = new WSDDDeployment(e);
      }
   }

   /**
    * @return XXX
    */
   public WSDDDeployment getDeployment()
   {
      if (deployment == null)
         deployment = new WSDDDeployment();
      return deployment;
   }

   public Document getDOMDocument() throws ConfigurationException
   {
      StringWriter writer = new StringWriter();
      SerializationContext context = new SerializationContextImpl(writer, null);
      context.setPretty(true);
      try
      {
         deployment.writeToContext(context);
      }
      catch (Exception e)
      {
         log.error(Messages.getMessage("exception00"), e);
      }
      try
      {
         writer.close();
         return XMLUtils.newDocument(new InputSource(new StringReader(writer.getBuffer().toString())));
      }
      catch (Exception e)
      {
         return null;
      }
   }

   public void writeToContext(SerializationContext context)
           throws IOException
   {
      getDeployment().writeToContext(context);
   }

   /**
    * @param document XXX
    */
   public void setDocument(Document document)
   {
      doc = document;

      deployment = null;
   }

   public void deploy(WSDDDeployment registry) throws ConfigurationException
   {
      if (deployment != null)
      {
         deployment.deployToRegistry(registry);
      }
      if (undeployment != null)
      {
         undeployment.undeployFromRegistry(registry);
      }
   }
}
